.. lattices documentation master file, created by
   sphinx-quickstart on Tue May 22 17:04:12 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

lattices
========

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
